"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fetchAndroidKeystoreAsync = fetchAndroidKeystoreAsync;
exports.fetchAndroidHashesAsync = fetchAndroidHashesAsync;
exports.fetchAndroidUploadCertAsync = fetchAndroidUploadCertAsync;

function _path() {
  const data = _interopRequireDefault(require("path"));

  _path = function () {
    return data;
  };

  return data;
}

function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function () {
    return data;
  };

  return data;
}

function _xdl() {
  const data = require("@expo/xdl");

  _xdl = function () {
    return data;
  };

  return data;
}

function _invariant() {
  const data = _interopRequireDefault(require("invariant"));

  _invariant = function () {
    return data;
  };

  return data;
}

function _AndroidCredentials() {
  const data = require("../../credentials/views/AndroidCredentials");

  _AndroidCredentials = function () {
    return data;
  };

  return data;
}

function _credentials() {
  const data = require("../../credentials");

  _credentials = function () {
    return data;
  };

  return data;
}

function _log() {
  const data = _interopRequireDefault(require("../../log"));

  _log = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function maybeRenameExistingFile(projectDir, filename) {
  let desiredFilePath = _path().default.resolve(projectDir, filename);

  if (await _fsExtra().default.pathExists(desiredFilePath)) {
    let num = 1;

    while (await _fsExtra().default.pathExists(_path().default.resolve(projectDir, `OLD_${num}_${filename}`))) {
      num++;
    }

    (0, _log().default)(`\nA file already exists at "${desiredFilePath}"\n  Renaming the existing file to OLD_${num}_${filename}\n`);
    await _fsExtra().default.rename(desiredFilePath, _path().default.resolve(projectDir, `OLD_${num}_${filename}`));
  }
}

async function fetchAndroidKeystoreAsync(projectDir) {
  const ctx = new (_credentials().Context)();
  await ctx.init(projectDir);
  const keystoreFilename = `${ctx.manifest.slug}.jks`;
  await maybeRenameExistingFile(projectDir, keystoreFilename);

  const backupKeystoreOutputPath = _path().default.resolve(projectDir, keystoreFilename);

  (0, _invariant().default)(ctx.manifest.slug, 'app.json slug field must be set');
  const view = new (_AndroidCredentials().DownloadKeystore)(ctx.manifest.slug);
  await view.fetch(ctx);
  await view.save(ctx, backupKeystoreOutputPath, true);
}

async function fetchAndroidHashesAsync(projectDir) {
  const ctx = new (_credentials().Context)();
  await ctx.init(projectDir);

  const outputPath = _path().default.resolve(projectDir, `${ctx.manifest.slug}.tmp.jks`);

  try {
    var _view$credentials, _view$credentials2;

    (0, _invariant().default)(ctx.manifest.slug, 'app.json slug field must be set');
    const view = new (_AndroidCredentials().DownloadKeystore)(ctx.manifest.slug);
    await view.fetch(ctx);
    await view.save(ctx, outputPath);
    await _xdl().AndroidCredentials.logKeystoreHashes({
      keystorePath: outputPath,
      // @ts-ignore keystorePassword can not be undefined
      keystorePassword: (_view$credentials = view.credentials) === null || _view$credentials === void 0 ? void 0 : _view$credentials.keystorePassword,
      // @ts-ignore keyAlias can not be undefined
      keyAlias: (_view$credentials2 = view.credentials) === null || _view$credentials2 === void 0 ? void 0 : _view$credentials2.keyAlias
    });
    (0, _log().default)(`\nNote: if you are using Google Play signing, this app will be signed with a different key after publishing to the store, and you'll need to use the hashes displayed in the Google Play console.`);
  } finally {
    try {
      _fsExtra().default.unlink(outputPath);
    } catch (err) {
      if (err.code !== 'ENOENT') {
        _log().default.error(err);
      }
    }
  }
}

async function fetchAndroidUploadCertAsync(projectDir) {
  const ctx = new (_credentials().Context)();
  await ctx.init(projectDir);

  const keystorePath = _path().default.resolve(projectDir, `${ctx.manifest.slug}.tmp.jks`);

  const uploadKeyFilename = `${ctx.manifest.slug}_upload_cert.pem`;
  await maybeRenameExistingFile(projectDir, uploadKeyFilename);

  const uploadKeyPath = _path().default.resolve(projectDir, uploadKeyFilename);

  try {
    var _view$credentials3, _view$credentials4;

    (0, _invariant().default)(ctx.manifest.slug, 'app.json slug field must be set');
    const view = new (_AndroidCredentials().DownloadKeystore)(ctx.manifest.slug);
    await view.fetch(ctx);
    await view.save(ctx, keystorePath);
    (0, _log().default)(`Writing upload key to ${uploadKeyPath}`);
    await _xdl().AndroidCredentials.exportCertBase64({
      keystorePath,
      // @ts-ignore keystorePassword can not be undefined
      keystorePassword: (_view$credentials3 = view.credentials) === null || _view$credentials3 === void 0 ? void 0 : _view$credentials3.keystorePassword,
      // @ts-ignore keyAlias can not be undefined
      keyAlias: (_view$credentials4 = view.credentials) === null || _view$credentials4 === void 0 ? void 0 : _view$credentials4.keyAlias
    }, uploadKeyPath);
  } finally {
    try {
      await _fsExtra().default.unlink(keystorePath);
    } catch (err) {
      if (err.code !== 'ENOENT') {
        _log().default.error(err);
      }
    }
  }
}
//# sourceMappingURL=android.js.map