"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

function _chalk() {
  const data = _interopRequireDefault(require("chalk"));

  _chalk = function () {
    return data;
  };

  return data;
}

function _xdl() {
  const data = require("@expo/xdl");

  _xdl = function () {
    return data;
  };

  return data;
}

function _CommandError() {
  const data = _interopRequireDefault(require("../CommandError"));

  _CommandError = function () {
    return data;
  };

  return data;
}

function _log() {
  const data = _interopRequireDefault(require("../log"));

  _log = function () {
    return data;
  };

  return data;
}

function _urlOpts() {
  const data = _interopRequireDefault(require("../urlOpts"));

  _urlOpts = function () {
    return data;
  };

  return data;
}

function _printRunInstructionsAsync() {
  const data = _interopRequireDefault(require("../printRunInstructionsAsync"));

  _printRunInstructionsAsync = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const logArtifactUrl = platform => async (projectDir, options) => {
  var _res$jobs, _res$jobs$filter$, _res$jobs$filter$$art;

  if (options.publicUrl && !_xdl().UrlUtils.isHttps(options.publicUrl)) {
    throw new (_CommandError().default)('INVALID_PUBLIC_URL', '--public-url must be a valid HTTPS URL.');
  }

  let res;

  if (process.env.EXPO_LEGACY_API === 'true') {
    res = await _xdl().Project.buildAsync(projectDir, {
      current: false,
      mode: 'status',
      ...(options.publicUrl ? {
        publicUrl: options.publicUrl
      } : {})
    });
  } else {
    res = await _xdl().Project.getBuildStatusAsync(projectDir, {
      current: false,
      ...(options.publicUrl ? {
        publicUrl: options.publicUrl
      } : {})
    });
  }

  const url = (_res$jobs = res.jobs) === null || _res$jobs === void 0 ? void 0 : (_res$jobs$filter$ = _res$jobs.filter(job => job.platform === platform)[0]) === null || _res$jobs$filter$ === void 0 ? void 0 : (_res$jobs$filter$$art = _res$jobs$filter$.artifacts) === null || _res$jobs$filter$$art === void 0 ? void 0 : _res$jobs$filter$$art.url;

  if (url) {
    _log().default.nested(url);
  } else {
    throw new Error(`No ${platform} binary file found. Use "expo build:${platform}" to create one.`);
  }
};

async function getWebAppUrlAsync(projectDir) {
  const webAppUrl = await _xdl().UrlUtils.constructWebAppUrlAsync(projectDir);

  if (!webAppUrl) {
    throw new (_CommandError().default)('NOT_RUNNING', `Expo web server is not running. Please start it with \`expo start:web\`.`);
  }

  return webAppUrl;
}

async function action(projectDir, options) {
  await _urlOpts().default.optsAsync(projectDir, options);

  if ((await _xdl().Project.currentStatus(projectDir)) !== 'running') {
    throw new (_CommandError().default)('NOT_RUNNING', `Project is not running. Please start it with \`expo start\`.`);
  }

  const url = options.web ? await getWebAppUrlAsync(projectDir) : await _xdl().UrlUtils.constructManifestUrlAsync(projectDir);

  _log().default.newLine();

  _urlOpts().default.printQRCode(url);

  (0, _log().default)('Your URL is\n\n' + _chalk().default.underline(url) + '\n');

  if (!options.web) {
    await (0, _printRunInstructionsAsync().default)();
    await _urlOpts().default.handleMobileOptsAsync(projectDir, options);
  }
}

function _default(program) {
  program.command('url [project-dir]').alias('u').option('-w, --web', 'Return the URL of the web app').description('Displays the URL you can use to view your project in Expo').urlOpts().allowOffline().asyncActionProjectDir(action);
  program.command('url:ipa [project-dir]').option('--public-url <url>', 'The URL of an externally hosted manifest (for self-hosted apps)').description('Displays the standalone iOS binary URL you can use to download your app binary').asyncActionProjectDir(logArtifactUrl('ios'));
  program.command('url:apk [project-dir]').option('--public-url <url>', 'The URL of an externally hosted manifest (for self-hosted apps)').description('Displays the standalone Android binary URL you can use to download your app binary').asyncActionProjectDir(logArtifactUrl('android'));
}
//# sourceMappingURL=url.js.map